/* List of defines generated by configure. Included with preprocessor flag,
 * -include, to avoid long list of -D defines on the compile command-line.
 * Do not edit.
 */

#ifndef _MOZILLA_CONFIG_H_
#define _MOZILLA_CONFIG_H_

#define ACCESSIBILITY 1
#define ATK_MAJOR_VERSION 1
#define ATK_MINOR_VERSION 28
#define ATK_REV_VERSION 0
#define ATTRIBUTE_ALIGNED_MAX 64
#define BREAKPAD_CUSTOM_STDINT_H "mozilla/StandardInteger.h"
#define BUILD_CTYPES 1
#define D_INO d_ino
#define ENABLE_SYSTEM_EXTENSION_DIRS 1
#define FIREFOX_VERSION 22.0a2
#define FUNCPROTO 15
#define GL_PROVIDER_GLX 1
#define HAVE_BYTESWAP_H 1
#define HAVE_CLOCK_MONOTONIC 1
#define HAVE_CPUID_H 1
#define HAVE_DIRENT_H 1
#define HAVE_DLADDR 1
#define HAVE_DLOPEN 1
#define HAVE_FCHMOD 1
#define HAVE_FLOCKFILE 1
#define HAVE_FONTCONFIG_FCFREETYPE_H 1
#define HAVE_FT_BITMAP_SIZE_Y_PPEM 1
#define HAVE_FT_GLYPHSLOT_EMBOLDEN 1
#define HAVE_FT_LOAD_SFNT_TABLE 1
#define HAVE_FT_SELECT_SIZE 1
#define HAVE_GETOPT_H 1
#define HAVE_GNU_GET_LIBC_VERSION 1
#define HAVE_GNU_LIBC_VERSION_H 1
#define HAVE_I18N_LC_MESSAGES 1
#define HAVE_INTTYPES_H 1
#define HAVE_ISATTY 1
#define HAVE_LANGINFO_CODESET 1
#define HAVE_LCHOWN 1
#define HAVE_LINUX_IF_ADDR_H 1
#define HAVE_LINUX_QUOTA_H 1
#define HAVE_LINUX_RTNETLINK_H 1
#define HAVE_LOCALECONV 1
#define HAVE_LOCALTIME_R 1
#define HAVE_LSTAT64 1
#define HAVE_MALLOC_H 1
#define HAVE_MALLOC_USABLE_SIZE 1
#define HAVE_MEMALIGN 1
#define HAVE_MEMMEM 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMORY_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NL_TYPES_H 1
#define HAVE_POSIX_FALLOCATE 1
#define HAVE_POSIX_MEMALIGN 1
#define HAVE_RANDOM 1
#define HAVE_RES_NINIT 1
#define HAVE_SETBUF 1
#define HAVE_SIGINFO_T 1
#define HAVE_SNPRINTF 1
#define HAVE_SSIZE_T 1
#define HAVE_STAT64 1
#define HAVE_STDINT_H 1
#define HAVE_STRERROR 1
#define HAVE_STRNDUP 1
#define HAVE_STRTOK_R 1
#define HAVE_ST_BLKSIZE 1
#define HAVE_SYS_BITYPES_H 1
#define HAVE_SYS_CDEFS_H 1
#define HAVE_SYS_QUOTA_H 1
#define HAVE_SYS_SYSMACROS_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_THREAD_TLS_KEYWORD 1
#define HAVE_TRUNCATE64 1
#define HAVE_UINT 1
#define HAVE_UINT64_T 1
#define HAVE_UNAME_DOMAINNAME_FIELD 1
#define HAVE_UNISTD_H 1
#define HAVE_VALLOC 1
#define HAVE_VA_COPY 1
#define HAVE_VISIBILITY_ATTRIBUTE 1
#define HAVE_VISIBILITY_HIDDEN_ATTRIBUTE 1
#define HAVE_X11_XKBLIB_H 1
#define HAVE__UNWIND_BACKTRACE 1
#define HAVE___CXA_DEMANGLE 1
#define IBMBIDI 1
#define JSGC_INCREMENTAL 1
#define JSGC_INCREMENTAL 1
#define JS_DEFAULT_JITREPORT_GRANULARITY 3
#define LIBJPEG_TURBO_X86_ASM 1
#define MALLOC_H <malloc.h>
#define MOZILLA_UAVERSION "22.0"
#define MOZILLA_VERSION "22.0a2"
#define MOZILLA_VERSION_U 22.0a2
#define MOZ_ACCESSIBILITY_ATK 1
#define MOZ_APP_UA_NAME ""
#define MOZ_APP_UA_VERSION "22.0a2"
#define MOZ_B2G_OS_NAME ""
#define MOZ_B2G_VERSION "1.0.0"
#define MOZ_BUILD_APP xulrunner
#define MOZ_CRASHREPORTER 1
#define MOZ_CRASHREPORTER_ENABLE_PERCENT 100
#define MOZ_CUBEB 1
#define MOZ_CUBEB 1
#define MOZ_DASH 1
#define MOZ_DATA_REPORTING 1
#define MOZ_DEBUG_SYMBOLS 1
#define MOZ_DISTRIBUTION_ID "org.mozilla"
#define MOZ_DLL_SUFFIX ".so"
#define MOZ_ENABLE_DBUS 1
#define MOZ_ENABLE_GCONF 1
#define MOZ_ENABLE_GIO 1
#define MOZ_ENABLE_PROFILER_SPS 1
#define MOZ_ENABLE_SKIA 1
#define MOZ_ENABLE_XREMOTE 1
#define MOZ_FEEDS 1
#define MOZ_FLEXBOX 1
#define MOZ_INSTRUMENT_EVENT_LOOP 1
#define MOZ_LOGGING 1
#define MOZ_MACBUNDLE_ID org.mozilla.xulrunner
#define MOZ_MEDIA 1
#define MOZ_MEDIA_NAVIGATOR 1
#define MOZ_MEMORY 1
#define MOZ_MEMORY_LINUX 1
#define MOZ_MEMORY_SIZEOF_PTR_2POW 2
#define MOZ_OGG 1
#define MOZ_OMNIJAR 1
#define MOZ_OPUS 1
#define MOZ_PANGO 1
#define MOZ_PDF_PRINTING 1
#define MOZ_PEERCONNECTION 1
#define MOZ_PLACES 1
#define MOZ_PROFILELOCKING 1
#define MOZ_RAW 1
#define MOZ_SAMPLE_TYPE_FLOAT32 1
#define MOZ_SCTP 1
#define MOZ_SERVICES_COMMON 1
#define MOZ_SERVICES_CRYPTO 1
#define MOZ_SERVICES_METRICS 1
#define MOZ_SERVICES_SYNC 1
#define MOZ_SIGNING 1
#define MOZ_SOUNDTOUCH 1
#define MOZ_SPEEX_RESAMPLER 1
#define MOZ_SRTP 1
#define MOZ_STATIC_JS 1
#define MOZ_TELEMETRY_DISPLAY_REV 2
#define MOZ_TREE_CAIRO 1
#define MOZ_TREE_PIXMAN 1
#define MOZ_UA_BUILDID ""
#define MOZ_UPDATER 1
#define MOZ_UPDATE_CHANNEL default
#define MOZ_URL_CLASSIFIER 1
#define MOZ_USER_DIR ".mozilla"
#define MOZ_VORBIS 1
#define MOZ_VP8 1
#define MOZ_VP8_ENCODER 1
#define MOZ_VP8_ERROR_CONCEALMENT 1
#define MOZ_WAVE 1
#define MOZ_WEBM 1
#define MOZ_WEBRTC 1
#define MOZ_WEBRTC_ASSERT_ALWAYS 1
#define MOZ_WEBRTC_SIGNALING 1
#define MOZ_WEBSPEECH 1
#define MOZ_WEBVTT 1
#define MOZ_WIDGET_GTK 2
#define MOZ_WIDGET_GTK2 1
#define MOZ_X11 1
#define MOZ_XUL 1
#define MOZ_XULRUNNER 1
#define NS_ATTR_MALLOC __attribute__((malloc))
#define NS_PRINTING 1
#define NS_PRINT_PREVIEW 1
#define NS_WARN_UNUSED_RESULT __attribute__((warn_unused_result))
#define SIZEOF_INT_P 4
#define STDC_HEADERS 1
#define USE_SKIA 1
#define USE_SKIA_GPU 1
#define VA_COPY va_copy
#define VPX_X86_ASM 1
#define XP_UNIX 1
#define _REENTRANT 1

/* The c99 defining the limit macros (UINT32_MAX for example), says:
 * C++ implementations should define these macros only when __STDC_LIMIT_MACROS
 * is defined before <stdint.h> is included. */
#define __STDC_LIMIT_MACROS

/* Force-include hunspell_alloc_hooks.h for hunspell, so that we don't need to
 * modify it directly.
 *
 * HUNSPELL_STATIC is defined in extensions/spellcheck/hunspell/src/Makefile.in,
 * unless --enable-system-hunspell is defined.
 */
#if defined(HUNSPELL_STATIC)
#include "hunspell_alloc_hooks.h"
#endif

#endif /* _MOZILLA_CONFIG_H_ */

